# coding=utf-8

from django.db import transaction

from utils.permission import IsAdministrator
from utils import response_error, response_ok
from utils.custom_modelviewset import CustomModelViewSet
from apps.staff.models import Department
from apps.staff.serializers import DepartmentSerializer
from apps.staff.filters import DepartmentFilter
from apps.system.models import SysLog


class DepartmentViewSet(CustomModelViewSet):
    permission_classes = [IsAdministrator, ]
    # queryset = Department.objects.filter(delete=False)
    queryset = Department.objects.filter()
    serializer_class = DepartmentSerializer

    def filter_queryset(self, queryset):
        f = DepartmentFilter(self.request.GET, queryset=queryset)
        return f.qs

    def perform_create(self, serializer):
        super(DepartmentViewSet, self).perform_create(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        SysLog.objects.addnew(self.request.user, SysLog.INSERT, u'添加部门[%s]，id=%d' % (instance.name, instance.id), validated_data)

    def destroy(self, request, *args, **kwargs):
        with transaction.atomic():
            instance = self.get_object()
            instance.delete = True
            instance.save()
            SysLog.objects.addnew(self.request.user, SysLog.DELETE, u'删除部门[%s]，id=%d' % (instance.name, instance.id))
        return response_ok()

    def perform_update(self, serializer):
        super(DepartmentViewSet, self).perform_update(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        SysLog.objects.addnew(self.request.user, SysLog.UPDATE, u'修改部门[%s]，id=%d' % (instance.name, instance.id), validated_data)
